@@ -146,8 +146,8 @@ class GreenStream(object):
         self.html = html
 
 
-    def __getattr__(self, attr):
-        return getattr(self.stream, attr)
+    def flush(self):
+        self.stream.flush()
 
 
     def writeln(self, text=''):
